==> cejs-4.5.1.tgz: package/application/locale/resources/sv-SE.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"Loading...": "Laddar...",
	"Load failed": "Kunde inte ladda",
	"Loading %1%...": "Laddar %1%...",
	"Initializing...": "Initierar...",
	"Contents of [%1]": "Inneh\u00e5ll av [%1]",
	"Contents": "Inneh\u00e5ll",
	"\u2191Back to TOC": "\u2191Tillbaka till inneh\u00e5llsf\u00f6rteckning",
	"expand": "visa",
	"collapse": "d\u00f6lj",
	"number": "nummer",
	"function": "funktion",
	"Illegal %1: [%2]": "Otill\u00e5ten %1: [%2]",
	"debug level": "fels\u00f6kningsniv\u00e5",
	"log-type-fatal": "kritisk",
	"log-type-error": "fel",
	"log-type-warn": "varna",
	"log-type-em": "emfas",
	"log-type-info": "info",
	"log-type-log": "logg",
	"log-type-debug": "fels\u00f6kning",
	"log-type-trace": "sp\u00e5r",
	"Language": "Spr\u00e5k",
	"\u6240\u6307\u5b9a\u4e4b domain [%1] \u5c1a\u672a\u8f09\u5165\uff0c\u82e5\u6709\u5fc5\u8981\u8acb\u4f7f\u7528\u5f37\u5236\u8f09\u5165 flag\u3002": "Angiven dom\u00e4n [%1] har \u00e4nnu inte laddats. Du kan beh\u00f6va ange FORCE-flagga.",
	"%1 elapsed, %3 at %2": "%1 passerad, %3 vid %2",
	"no change": "ingen \u00e4ndring",
	"finished": "klar",
	"finished: %1": "klar: %1",
	"First, it takes %1 to get %2 pages.": "F\u00f6rst tar den %1 och f\u00e5r %2 sidor.",
	"%1 page(s) processed,": "%1 sidor bearbetade.",
	"no page modified,": "ingen sida modifierad,",
	"%1 page(s) have not changed,": "%1 sidor har inte \u00e4ndrats,",
	"%1 elapsed.": "%1 passerad.",
	"'''Stopped''', give up editing.": "'''Stannade''', \u00f6verge redigering.",
	"No changes.": "Inga \u00e4ndringar.",
	"Continue key": "Forts\u00e4ttningsnyckel",
	"Abandon change": "\u00d6verge \u00e4ndring",
	"No reason provided": "Ingen anledning gavs",
	"Content is empty": "Inneh\u00e5llet \u00e4r tomt",
	"Content is not settled": "Inneh\u00e5llet har inte etablerats",
	"%1 Y %2 M": "%1 \u00e5r %2 m",
	"%1 Y": "%1 \u00e5r",
	"%1 M": "%1 m",
	"%1 ms": "%1 ms",
	"%1 s": "%1 s",
	"%1 min": "%1 min",
	"%1 hr": "%1 tm",
	"%1 d": "%1 d",
	"now": "nu",
	"several seconds ago": "flera sekunder sedan",
	"soon": "snart",
	"%1 seconds ago": "%1 sekunder sen",
	"%1 seconds later": "%1 sekunder senare",
	"%1 minutes ago": "%1 minuter sedan",
	"%1 minutes later": "%1 minuter senare",
	"%1 hours ago": "%1 timme sedan",
	"%1 hours later": "%1 timme senare",
	"2 days before yesterday, %H:%M": "I f\u00f6rrf\u00f6rrg\u00e5r, %H:%M",
	"the day before yesterday, %H:%M": "i f\u00f6rrg\u00e5r, %H:%M",
	"yesterday, %H:%M": "ig\u00e5r, %H:%M",
	"today, %H:%M": "idag, %H:%M",
	"tomorrow, %H:%M": "imorgon, %H:%M",
	"the day after tomorrow, %H:%M": "i \u00f6vermorgon, %H:%M",
	"2 days after tomorrow, %H:%M": "i \u00f6ver\u00f6vermorgon, %H:%M",
	"3 days after tomorrow, %H:%M": "om fyra dagar, %H:%M",
	"%1 days ago": "%1 dag sedan",
	"%1 days later": "%1 dagar senare",
	"%1 weeks ago": "%1 veckor sedan",
	"%1 weeks later": "%1 veckor senare",
	"\u8df3\u904e [%1]\uff1a\u672c[%2]\u50c5\u4f9b\u53c3\u7167\u7528\u3002": "Hoppa \u00f6ver [%1]: %2 ska bara anv\u00e4ndas f\u00f6r referenser.",
	"\u7d00\u5e74 %1": "Era %1",
	"\u8a0a\u606f\u63d0\u793a\u8207\u7d00\u9304\u6b04": "Journalpanel",
	"\u5df2\u8f09\u5165 %1 \u7b46\u8cc7\u6599\u3002": function (domain_name, arg) { return '%1 ' + (1 < arg[1] ? 'inlägg' : 'inlägg') + ' laddad.'; },
	"\u8acb\u6ce8\u610f\uff1a\u672c\u6b04\u50c5\u4f9b\u958b\u767c\u4eba\u54e1\u4f7f\u7528\u3002": "VARNING: Endast f\u00f6r utvecklare.",
	"\u7d04%1\u5e74": "ungef. %1",
	"\u4e2d\u570b": "Kina",
	"\u65e5\u672c": "Japan",
	"\ud55c\uad6d": "Korea",
	"\u7409\u7403": "Ryukyu",
	"Vi\u1ec7t Nam": "Vietnam",
	"B\u1eafc thu\u1ed9c": "Kinesisk dominans \u00f6ver Vietnam",
	"Th\u1eddi k\u1ef3 \u0111\u1ed9c l\u1eadp": "Sen dynastisk epok",
	"\u0e44\u0e17\u0e22": "Thailand",
	"India": "Indien",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "Myanmar",
	"Persia": "Persien",
	"\u1f08\u03b8\u1fc6\u03bd\u03b1\u03b9": "Klassiska Aten",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "Sparta",
	"\u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1": "Makedonien",
	"\u7d00\u5e74": "Erans namn",
	"\u8f38\u51fa\u683c\u5f0f": "Utmatningsformat",
	"\u4e2d\u6587\u6578\u5b57": "Till kinesiska siffror",
	"\u6e2c\u8a66\u7bc4\u4f8b": "EXEMPEL",
	"\u8f38\u5165\u7d00\u9304": "REGISTRERING",
	"\u4f7f\u7528\u8aaa\u660e": "KONCEPT",
	"\u7d00\u5e74\u7dda\u5716": "TIDSLINJE",
	"\u66c6\u8b5c": "KALENDERTABELL",
	"\u8a2d\u5b9a": "KONFIGURERING",
	"\u6279\u6b21\u8f49\u63db": "BUNT",
	"\u6a19\u6ce8\u6587\u672c": "TAGGNING",
	"\u66c6\u6578\u8655\u7406": "UTVECKLING",
	"\u554f\u984c\u56de\u5831": "\u00c5TERKOPPLING",
	"\u7121\u53ef\u4f9b\u5217\u51fa\u4e4b\u66c6\u8b5c\uff01": "Ingen kalender att lista!",
	"\u5617\u8a66\u52a0\u6ce8\u65e5\u671f": "Testa att tillfoga datum",
	"\u5e74\u8b5c": "kalenderdatum",
	"\u5171\u6709 %1 \u500b\u6642\u6bb5\u7d00\u9304": "%1 registreringar",
	"\u5171\u6709 %1 \u500b\u5e74\u6bb5\u7d00\u9304": "%1 \u00e5r",
	"%1 BCE": "%1 f.v.t.",
	"%1 CE": "%1 f.v.t.",
	"\u5e74\u865f": "Datum i era",
	"\u63a1\u7528\u66c6\u6cd5": "Kalender som anv\u00e4nds",
	"\u6ce8": "Anteckning",
	"\u5c55\u793a\u7dda\u5716": "Visar tidslinje",
	"\u541b\u4e3b\u540d": "Personnamn",
	"\u8868\u5b57": "Artighetsnamn",
	"\u541b\u4e3b\u865f": "Artistnamn",
	"\u8af1": "Riktigt namn",
	"\u8ae1": "Postumt namn",
	"\u5edf\u865f": "Tempelnamn",
	"\u51fa\u751f": "F\u00f6dd",
	"\u901d\u4e16": "D\u00f6d",
	"\u5728\u4f4d": "Styre",
	"\u52a0\u5195": "Kr\u00f6ning",
	"\u7236\u89aa": "Far",
	"\u6bcd\u89aa": "Mor",
	"\u524d\u4efb": "F\u00f6reg\u00e5ngare",
	"\u7e7c\u4efb": "Eftertr\u00e4dare",
	"\u914d\u5076": "Make/maka",
	"\u524d\u7db4": "prefix",
	"\u589e\u52a0\u6b64\u6b04": "L\u00e4gg till kolumnen",
	"\u9664\u53bb\u6b64\u6b04": "Ta bort kolumnen",
	"\u5168\u4e0d\u9078": "Ta bort ALLT",
	"Pin": "F\u00e4st",
	"Unpin": "L\u00f6sg\u00f6r",
	"\u5206\u985e": "Gruppera",
	"\u66c6\u6ce8": "Kalenderanteckning",
	"\u661f\u671f": "Veckodag",
	"Gregorian calendar": "Gregorianska kalendern",
	"Julian calendar": "Julianska kalendern",
	"Julian Date": "Julianskt datum",
	"Julian Day Number": "Julianskt datumnummer",
	"\u9031\u65e5\u671f": "Veckodatum",
	"astronomy": "astronomi",
	"calendar": "kalender",
	"untranslated message count": "906"
},
"sv-SE");

==> cejs-4.5.2.tgz: package/application/locale/resources/sv-SE.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"untranslated message count": "1000+",
	"Load failed": "Kunde inte ladda",
	"\u8a0a\u606f\u63d0\u793a\u8207\u7d00\u9304\u6b04": "Journalpanel",
	"\u8f38\u51fa\u683c\u5f0f": "Utmatningsformat",
	"\u524d\u7db4": "prefix",
	"\u8acb\u6ce8\u610f\uff1a\u672c\u6b04\u50c5\u4f9b\u958b\u767c\u4eba\u54e1\u4f7f\u7528\u3002": "VARNING: Endast f\u00f6r utvecklare.",
	"\u6279\u6b21\u8f49\u63db": "BUNT",
	"Loading...": "Laddar...",
	"\u6e2c\u8a66\u7bc4\u4f8b": "EXEMPEL",
	"\u8f38\u5165\u7d00\u9304": "REGISTRERING",
	"\u4f7f\u7528\u8aaa\u660e": "KONCEPT",
	"\u7d00\u5e74\u7dda\u5716": "TIDSLINJE",
	"\u66c6\u8b5c": "KALENDERTABELL",
	"\u8a2d\u5b9a": "KONFIGURERING",
	"\u6a19\u6ce8\u6587\u672c": "TAGGNING",
	"\u66c6\u6578\u8655\u7406": "UTVECKLING",
	"\u554f\u984c\u56de\u5831": "\u00c5TERKOPPLING",
	"Julian Day Number": "Julianskt datumnummer",
	"\u7d04%1\u5e74": "ungef. %1",
	"Vi\u1ec7t Nam": "Vietnam",
	"\u63a1\u7528\u66c6\u6cd5": "Kalender som anv\u00e4nds",
	"\u541b\u4e3b\u540d": "Personnamn",
	"\u8868\u5b57": "Artighetsnamn",
	"\u541b\u4e3b\u865f": "Artistnamn",
	"\u8af1": "Riktigt namn",
	"\u8ae1": "Postumt namn",
	"\u5edf\u865f": "Tempelnamn",
	"\u51fa\u751f": "F\u00f6dd",
	"\u901d\u4e16": "D\u00f6d",
	"\u5728\u4f4d": "Styre",
	"\u52a0\u5195": "Kr\u00f6ning",
	"\u524d\u4efb": "F\u00f6reg\u00e5ngare",
	"\u7e7c\u4efb": "Eftertr\u00e4dare",
	"\u7236\u89aa": "Far",
	"\u6bcd\u89aa": "Mor",
	"\u914d\u5076": "Make/maka",
	"\u5c55\u793a\u7dda\u5716": "Visar tidslinje",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "Myanmar",
	"\u7d00\u5e74 %1": "Era %1",
	"Unpin": "L\u00f6sg\u00f6r",
	"Pin": "F\u00e4st",
	"Initializing...": "Initierar...",
	"\u5df2\u8f09\u5165 %1 \u7b46\u8cc7\u6599\u3002": function (domain_name, arg) { return '%1 ' + (1 < arg[1] ? 'inlägg' : 'inlägg') + ' laddad.'; },
	"\u661f\u671f": "Veckodag",
	"Julian Date": "Julianskt datum",
	"\u9031\u65e5\u671f": "Veckodatum",
	"\u9664\u53bb\u6b64\u6b04": "Ta bort kolumnen",
	"calendar": "kalender",
	"Gregorian calendar": "Gregorianska kalendern",
	"Julian calendar": "Julianska kalendern",
	"\u5206\u985e": "Gruppera",
	"\u66c6\u6ce8": "Kalenderanteckning",
	"\u4e2d\u570b": "Kina",
	"%1 BCE": "%1 f.v.t.",
	"%1 CE": "%1 f.v.t.",
	"\u5e74\u8b5c": "kalenderdatum",
	"\u5171\u6709 %1 \u500b\u6642\u6bb5\u7d00\u9304": "%1 registreringar",
	"\u5171\u6709 %1 \u500b\u5e74\u6bb5\u7d00\u9304": "%1 \u00e5r",
	"\u7121\u53ef\u4f9b\u5217\u51fa\u4e4b\u66c6\u8b5c\uff01": "Ingen kalender att lista!",
	"\u5617\u8a66\u52a0\u6ce8\u65e5\u671f": "Testa att tillfoga datum",
	"\u5168\u4e0d\u9078": "Ta bort ALLT",
	"\u589e\u52a0\u6b64\u6b04": "L\u00e4gg till kolumnen",
	"finished": "klar",
	"No changes.": "Inga \u00e4ndringar.",
	"no page modified,": "ingen sida modifierad,",
	"\u4e2d\u6587\u6578\u5b57": "Till kinesiska siffror",
	"astronomy": "astronomi",
	"Loading %1%...": "Laddar %1%...",
	"log-type-debug": "fels\u00f6kning",
	"log-type-em": "emfas",
	"log-type-error": "fel",
	"log-type-fatal": "kritisk",
	"log-type-info": "info",
	"log-type-log": "logg",
	"log-type-trace": "sp\u00e5r",
	"log-type-warn": "varna",
	"\u6240\u6307\u5b9a\u4e4b domain [%1] \u5c1a\u672a\u8f09\u5165\uff0c\u82e5\u6709\u5fc5\u8981\u8acb\u4f7f\u7528\u5f37\u5236\u8f09\u5165 flag\u3002": "Angiven dom\u00e4n [%1] har \u00e4nnu inte laddats. Du kan beh\u00f6va ange FORCE-flagga.",
	"Language": "Spr\u00e5k",
	"Content is empty": "Inneh\u00e5llet \u00e4r tomt",
	"Content is not settled": "Inneh\u00e5llet har inte etablerats",
	"Abandon change": "\u00d6verge \u00e4ndring",
	"No reason provided": "Ingen anledning gavs",
	"Continue key": "Forts\u00e4ttningsnyckel",
	"no change": "ingen \u00e4ndring",
	"finished: %1": "klar: %1",
	"%1 elapsed, %3 at %2": "%1 passerad, %3 vid %2",
	"First, it takes %1 to get %2 {{PLURAL:%2|page|pages}}.": "F\u00f6rst tar den %1 och f\u00e5r %2 sidor.",
	"%1 {{PLURAL:%1|page|pages}} processed": "%1 sidor bearbetade.",
	"%1 {{PLURAL:%1|page|pages}} have not changed,": "%1 sidor har inte \u00e4ndrats,",
	"%1 elapsed.": "%1 passerad.",
	"'''Stopped''', give up editing.": "'''Stannade''', \u00f6verge redigering.",
	"function": "funktion",
	"number": "nummer",
	"Contents": "Inneh\u00e5ll",
	"%1 Y %2 M": "%1 \u00e5r %2 m",
	"%1 Y": "%1 \u00e5r",
	"%1 M": "%1 m",
	"%1 ms": "%1 ms",
	"%1 s": "%1 s",
	"%1 min": "%1 min",
	"%1 hr": "%1 tm",
	"%1 d": "%1 d",
	"2 days before yesterday, %H:%M": "I f\u00f6rrf\u00f6rrg\u00e5r, %H:%M",
	"the day before yesterday, %H:%M": "i f\u00f6rrg\u00e5r, %H:%M",
	"yesterday, %H:%M": "ig\u00e5r, %H:%M",
	"today, %H:%M": "idag, %H:%M",
	"tomorrow, %H:%M": "imorgon, %H:%M",
	"the day after tomorrow, %H:%M": "i \u00f6vermorgon, %H:%M",
	"2 days after tomorrow, %H:%M": "i \u00f6ver\u00f6vermorgon, %H:%M",
	"3 days after tomorrow, %H:%M": "om fyra dagar, %H:%M",
	"now": "nu",
	"several seconds ago": "flera sekunder sedan",
	"soon": "snart",
	"%1 {{PLURAL:%1|second|seconds}} ago": "%1 sekunder sen",
	"%1 {{PLURAL:%1|second|seconds}} later": "%1 sekunder senare",
	"%1 {{PLURAL:%1|minute|minutes}} ago": "%1 minuter sedan",
	"%1 {{PLURAL:%1|minute|minutes}} later": "%1 minuter senare",
	"%1 {{PLURAL:%1|hour|hours}} ago": "%1 timme sedan",
	"%1 {{PLURAL:%1|hour|hours}} later": "%1 timme senare",
	"%1 {{PLURAL:%1|day|days}} ago": "%1 dag sedan",
	"%1 {{PLURAL:%1|day|days}} later": "%1 dagar senare",
	"%1 {{PLURAL:%1|week|weeks}} ago": "%1 veckor sedan",
	"%1 {PLURAL:%1|week|weeks}} later": "%1 veckor senare",
	"\u6ce8": "Anteckning",
	"\u7d00\u5e74": "Erans namn",
	"\u5e74\u865f": "Datum i era",
	"\u8df3\u904e [%1]\uff1a\u672c[%2]\u50c5\u4f9b\u53c3\u7167\u7528\u3002": "Hoppa \u00f6ver [%1]: %2 ska bara anv\u00e4ndas f\u00f6r referenser.",
	"\u7409\u7403": "Ryukyu",
	"\u65e5\u672c": "Japan",
	"\ud55c\uad6d": "Korea",
	"B\u1eafc thu\u1ed9c": "Kinesisk dominans \u00f6ver Vietnam",
	"Th\u1eddi k\u1ef3 \u0111\u1ed9c l\u1eadp": "Sen dynastisk epok",
	"\u0e44\u0e17\u0e22": "Thailand",
	"India": "Indien",
	"Persia": "Persien",
	"\u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1": "Makedonien",
	"\u1f08\u03b8\u1fc6\u03bd\u03b1\u03b9": "Klassiska Aten",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "Sparta",
	"\u2191Back to TOC": "\u2191Tillbaka till inneh\u00e5llsf\u00f6rteckning",
	"Contents of [%1]": "Inneh\u00e5ll av [%1]",
	"expand": "visa",
	"collapse": "d\u00f6lj",
	"Illegal %1: [%2]": "Otill\u00e5ten %1: [%2]",
	"debug level": "fels\u00f6kningsniv\u00e5"
},
"sv-SE");
